@@ -116,37 +116,37 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="145"/>
+        <location filename="../mainWindow.py" line="154"/>
         <source>Double-clic non pris en compte</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="145"/>
+        <location filename="../mainWindow.py" line="154"/>
         <source>pas d&apos;action pour l&apos;attribut %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="265"/>
+        <location filename="../mainWindow.py" line="285"/>
         <source>Veuillez choisir au moins un fichier</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="261"/>
+        <location filename="../mainWindow.py" line="281"/>
         <source>Choix de la destination ...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="292"/>
+        <location filename="../mainWindow.py" line="312"/>
         <source>Voir les copies</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="297"/>
+        <location filename="../mainWindow.py" line="317"/>
         <source>Destination manquante</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="297"/>
+        <location filename="../mainWindow.py" line="317"/>
         <source>Veuillez choisir une destination pour la copie des fichiers</source>
         <translation type="unfinished"></translation>
     </message>
@@ -191,22 +191,22 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="160"/>
+        <location filename="../ownedUsbDisk.py" line="161"/>
         <source>inconnu</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="199"/>
+        <location filename="../ownedUsbDisk.py" line="202"/>
         <source>La cle %1&lt;br&gt;n&apos;est pas identifiee, donnez le nom du proprietaire</source>
         <translation>La clé %1&lt;br&gt;n&apos;est pas identifiée, donnez le nom du propriétaire</translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="200"/>
+        <location filename="../ownedUsbDisk.py" line="203"/>
         <source>Entrer un nom</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="221"/>
+        <location filename="../mainWindow.py" line="243"/>
         <source>Vous allez effacer plusieurs baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
@@ -301,32 +301,32 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="216"/>
+        <location filename="../mainWindow.py" line="238"/>
         <source>Choix de fichiers à supprimer (jokers autorisés)</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="265"/>
+        <location filename="../mainWindow.py" line="285"/>
         <source>Aucun fichier sélectionné</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="259"/>
+        <location filename="../mainWindow.py" line="279"/>
         <source>Choix de fichiers à copier</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="260"/>
+        <location filename="../mainWindow.py" line="280"/>
         <source>Choix de fichiers à copier depuis les baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="273"/>
+        <location filename="../mainWindow.py" line="293"/>
         <source>Choisir un répertoire de destination</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="292"/>
+        <location filename="../mainWindow.py" line="312"/>
         <source>Voulez-vous voir les fichiers copiés ?</source>
         <translation type="unfinished"></translation>
     </message>
@@ -344,47 +344,47 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="318"/>
+        <location filename="../mainWindow.py" line="337"/>
         <source>Démontage des baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="318"/>
+        <location filename="../mainWindow.py" line="337"/>
         <source>Êtes-vous sûr de vouloir démonter tous les baladeurs cochés de la liste ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="422"/>
+        <location filename="../mainWindow.py" line="477"/>
         <source>Cocher ou décocher cette case en cliquant.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="424"/>
+        <location filename="../mainWindow.py" line="479"/>
         <source>Propriétaire de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour modifier.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="426"/>
+        <location filename="../mainWindow.py" line="481"/>
         <source>Point de montage de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir les fichiers.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="428"/>
+        <location filename="../mainWindow.py" line="483"/>
         <source>Capacité de la clé USB ou du baladeur en kO ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir la place occupée.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="430"/>
+        <location filename="../mainWindow.py" line="485"/>
         <source>Fabricant de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="432"/>
+        <location filename="../mainWindow.py" line="487"/>
         <source>Modèle de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="434"/>
+        <location filename="../mainWindow.py" line="489"/>
         <source>Numéro de série de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -397,7 +397,7 @@ p, li { white-space: pre-wrap; }
         <translation>Taille du disque</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="126"/>
+        <location filename="../Ui_mainWindow.py" line="143"/>
         <source>...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -412,55 +412,85 @@ p, li { white-space: pre-wrap; }
         <translation>Utilisé(s)</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="107"/>
+        <location filename="../Ui_mainWindow.py" line="119"/>
         <source>ScolaSync</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="108"/>
+        <location filename="../Ui_mainWindow.py" line="120"/>
         <source>Actions</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="110"/>
+        <location filename="../Ui_mainWindow.py" line="42"/>
         <source>Copier depuis les cles</source>
-        <translation>Copier depuis les clés</translation>
+        <translation type="obsolete">Copier depuis les clés</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="113"/>
+        <location filename="../Ui_mainWindow.py" line="54"/>
         <source>Copier vers les cles</source>
-        <translation>Copier vers les clés</translation>
+        <translation type="obsolete">Copier vers les clés</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="119"/>
+        <location filename="../Ui_mainWindow.py" line="78"/>
         <source>Demonter les cles</source>
-        <translation>Démonter les clés</translation>
+        <translation type="obsolete">Démonter les clés</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="122"/>
+        <location filename="../Ui_mainWindow.py" line="90"/>
         <source>Preferences</source>
-        <translation>Préférences</translation>
+        <translation type="obsolete">Préférences</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="125"/>
+        <location filename="../Ui_mainWindow.py" line="142"/>
         <source>Aide</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="116"/>
-        <source>Supprimer dans les clés</source>
+        <location filename="../Ui_mainWindow.py" line="137"/>
+        <source>Force à recompter les baladeurs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_mainWindow.py" line="140"/>
+        <source>Affiche le nombre de baladeurs connectés</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_mainWindow.py" line="122"/>
+        <source>Copier depuis les baladeurs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_mainWindow.py" line="125"/>
+        <source>Copier vers les baladeurs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_mainWindow.py" line="128"/>
+        <source>Effacer des fichiers ou des dossiers dans les baladeurs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_mainWindow.py" line="131"/>
+        <source>Demonter les baladeurs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_mainWindow.py" line="134"/>
+        <source>Préférences</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context encoding="UTF-8">
     <name>diskFull</name>
     <message encoding="UTF-8">
-        <location filename="../diskFull.py" line="55"/>
+        <location filename="../diskFull.py" line="49"/>
         <source>Place totale : %1 kilo-octets</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../diskFull.py" line="56"/>
+        <location filename="../diskFull.py" line="50"/>
         <source>Place utilisée : %1 kilo-octets</source>
         <translation type="unfinished"></translation>
     </message>
@@ -477,18 +507,13 @@ p, li { white-space: pre-wrap; }
         <source>taille</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../usbDisk.py" line="65"/>
-        <source>vendeur</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../usbDisk.py" line="70"/>
         <source>cocher</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="144"/>
+        <location filename="../ownedUsbDisk.py" line="145"/>
         <source>owner</source>
         <translation>propriétaire</translation>
     </message>
@@ -502,5 +527,10 @@ p, li { white-space: pre-wrap; }
         <source>numéro de série</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../usbDisk.py" line="65"/>
+        <source>marque</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
