@@ -231,67 +231,67 @@ p, li { white-space: pre-wrap; }(new line)
         <translation>Continuar...</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="145"/>
+        <location filename="../mainWindow.py" line="154"/>
         <source>Double-clic non pris en compte</source>
         <translation>Clique-duplo não é considerado</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="145"/>
+        <location filename="../mainWindow.py" line="154"/>
         <source>pas d&apos;action pour l&apos;attribut %1</source>
         <translation>sem ação para o atributo %1</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="216"/>
+        <location filename="../mainWindow.py" line="238"/>
         <source>Choix de fichiers à supprimer (jokers autorisés)</source>
         <translation>Escolha de ficheiros a suprimir (jokers autorizados)</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="265"/>
+        <location filename="../mainWindow.py" line="285"/>
         <source>Aucun fichier sélectionné</source>
         <translation>Nenhum ficheiro selecionado</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="265"/>
+        <location filename="../mainWindow.py" line="285"/>
         <source>Veuillez choisir au moins un fichier</source>
         <translation>Escolha pelo menos um ficheiro</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="259"/>
+        <location filename="../mainWindow.py" line="279"/>
         <source>Choix de fichiers à copier</source>
         <translation>Escolha de ficheiros a copiar</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="260"/>
+        <location filename="../mainWindow.py" line="280"/>
         <source>Choix de fichiers à copier depuis les baladeurs</source>
         <translation>Escolha de ficheiros a copiar a partir dos leitores</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="261"/>
+        <location filename="../mainWindow.py" line="281"/>
         <source>Choix de la destination ...</source>
         <translation>Escolha do destino ...</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="273"/>
+        <location filename="../mainWindow.py" line="293"/>
         <source>Choisir un répertoire de destination</source>
         <translation>Escolher uma pasta de destinação</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="292"/>
+        <location filename="../mainWindow.py" line="312"/>
         <source>Voir les copies</source>
         <translation>Ver os devers</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="292"/>
+        <location filename="../mainWindow.py" line="312"/>
         <source>Voulez-vous voir les fichiers copiés ?</source>
         <translation>Quer ver os ficheiros copiados ?</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="297"/>
+        <location filename="../mainWindow.py" line="317"/>
         <source>Destination manquante</source>
         <translation>Falta de destinação</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="297"/>
+        <location filename="../mainWindow.py" line="317"/>
         <source>Veuillez choisir une destination pour la copie des fichiers</source>
         <translation>Escolha um destino para a cópia dos ficheiros</translation>
     </message>
@@ -321,22 +321,22 @@ p, li { white-space: pre-wrap; }(new line)
         <translation>%s gigabytes</translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="160"/>
+        <location filename="../ownedUsbDisk.py" line="161"/>
         <source>inconnu</source>
         <translation>desconhecido</translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="199"/>
+        <location filename="../ownedUsbDisk.py" line="202"/>
         <source>La cle %1&lt;br&gt;n&apos;est pas identifiee, donnez le nom du proprietaire</source>
         <translation>A chave %1&lt;br&gt;não està identificada, dê o nome do dono</translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="200"/>
+        <location filename="../ownedUsbDisk.py" line="203"/>
         <source>Entrer un nom</source>
         <translation>Escreva um nome</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="221"/>
+        <location filename="../mainWindow.py" line="243"/>
         <source>Vous allez effacer plusieurs baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
@@ -349,47 +349,47 @@ p, li { white-space: pre-wrap; }(new line)
         <translation>Versão número %1.%2</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="318"/>
+        <location filename="../mainWindow.py" line="337"/>
         <source>Démontage des baladeurs</source>
         <translation>Desmontagem dos leitores</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="318"/>
+        <location filename="../mainWindow.py" line="337"/>
         <source>Êtes-vous sûr de vouloir démonter tous les baladeurs cochés de la liste ?</source>
         <translation>Tem a certeza de querer desmontar todos os leitores assinalados ?</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="422"/>
+        <location filename="../mainWindow.py" line="477"/>
         <source>Cocher ou décocher cette case en cliquant.</source>
         <translation>Assinalar ou desmarcar esta casa clicando.</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="424"/>
+        <location filename="../mainWindow.py" line="479"/>
         <source>Propriétaire de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour modifier.</source>
         <translation>Dono da chave ou do leitor ;&lt;br&gt;&lt;b&gt;Clique-duplo&lt;/b&gt; para modificar.</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="426"/>
+        <location filename="../mainWindow.py" line="481"/>
         <source>Point de montage de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir les fichiers.</source>
         <translation>Ponto de montagem da chave ou do leitor ; &lt;br&gt;&lt;b&gt;Clique-duplo&lt;/b&gt; para ver os ficheiros.</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="428"/>
+        <location filename="../mainWindow.py" line="483"/>
         <source>Capacité de la clé USB ou du baladeur en kO ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir la place occupée.</source>
         <translation>Capacidade da chave USB ou do leitor en kB ;&lt;br&gt;&lt;b&gt;Clique-duplo&lt;/b&gt; para ver o espaço ocupado.</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="430"/>
+        <location filename="../mainWindow.py" line="485"/>
         <source>Fabricant de la clé USB ou du baladeur.</source>
         <translation>Fabricante da chave USB ou do leitor.</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="432"/>
+        <location filename="../mainWindow.py" line="487"/>
         <source>Modèle de la clé USB ou du baladeur.</source>
         <translation>Modelo da chave ou do leitor.</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="434"/>
+        <location filename="../mainWindow.py" line="489"/>
         <source>Numéro de série de la clé USB ou du baladeur.</source>
         <translation>Número de série da chave ou do leitor.</translation>
     </message>
@@ -397,47 +397,47 @@ p, li { white-space: pre-wrap; }(new line)
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../Ui_mainWindow.py" line="107"/>
+        <location filename="../Ui_mainWindow.py" line="119"/>
         <source>ScolaSync</source>
         <translation>Scolasync</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="108"/>
+        <location filename="../Ui_mainWindow.py" line="120"/>
         <source>Actions</source>
         <translation>Ações</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="110"/>
+        <location filename="../Ui_mainWindow.py" line="42"/>
         <source>Copier depuis les cles</source>
-        <translation>Copiar a partir dos leitores</translation>
+        <translation type="obsolete">Copiar a partir dos leitores</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="126"/>
+        <location filename="../Ui_mainWindow.py" line="143"/>
         <source>...</source>
         <translation>... </translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="113"/>
+        <location filename="../Ui_mainWindow.py" line="54"/>
         <source>Copier vers les cles</source>
-        <translation>Copiar para os leitores</translation>
+        <translation type="obsolete">Copiar para os leitores</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="116"/>
+        <location filename="../Ui_mainWindow.py" line="66"/>
         <source>Supprimer dans les clés</source>
-        <translation>Suprimir nos leitores</translation>
+        <translation type="obsolete">Suprimir nos leitores</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="119"/>
+        <location filename="../Ui_mainWindow.py" line="78"/>
         <source>Demonter les cles</source>
-        <translation>Desmontar os leitores</translation>
+        <translation type="obsolete">Desmontar os leitores</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="122"/>
+        <location filename="../Ui_mainWindow.py" line="90"/>
         <source>Preferences</source>
-        <translation>Preferéncias</translation>
+        <translation type="obsolete">Preferéncias</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="125"/>
+        <location filename="../Ui_mainWindow.py" line="142"/>
         <source>Aide</source>
         <translation>Ajuda</translation>
     </message>
@@ -456,16 +456,51 @@ p, li { white-space: pre-wrap; }(new line)
         <source>Used</source>
         <translation>Utilizado</translation>
     </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_mainWindow.py" line="137"/>
+        <source>Force à recompter les baladeurs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_mainWindow.py" line="140"/>
+        <source>Affiche le nombre de baladeurs connectés</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_mainWindow.py" line="122"/>
+        <source>Copier depuis les baladeurs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_mainWindow.py" line="125"/>
+        <source>Copier vers les baladeurs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_mainWindow.py" line="128"/>
+        <source>Effacer des fichiers ou des dossiers dans les baladeurs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_mainWindow.py" line="131"/>
+        <source>Demonter les baladeurs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_mainWindow.py" line="134"/>
+        <source>Préférences</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context encoding="UTF-8">
     <name>diskFull</name>
     <message encoding="UTF-8">
-        <location filename="../diskFull.py" line="55"/>
+        <location filename="../diskFull.py" line="49"/>
         <source>Place totale : %1 kilo-octets</source>
         <translation>Lugar total : %1 kilobytes</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../diskFull.py" line="56"/>
+        <location filename="../diskFull.py" line="50"/>
         <source>Place utilisée : %1 kilo-octets</source>
         <translation>Lugar utilizado : %1 kilobytes</translation>
     </message>
@@ -485,7 +520,7 @@ p, li { white-space: pre-wrap; }(new line)
     <message>
         <location filename="../usbDisk.py" line="65"/>
         <source>vendeur</source>
-        <translation>vendedor</translation>
+        <translation type="obsolete">vendedor</translation>
     </message>
     <message encoding="UTF-8">
         <location filename="../usbDisk.py" line="66"/>
@@ -503,9 +538,14 @@ p, li { white-space: pre-wrap; }(new line)
         <translation>assinalar</translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="144"/>
+        <location filename="../ownedUsbDisk.py" line="145"/>
         <source>owner</source>
         <translation>dono</translation>
     </message>
+    <message>
+        <location filename="../usbDisk.py" line="65"/>
+        <source>marque</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
