@@ -25,14 +25,15 @@ licence['en']="""
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
-import ownedUsbDisk, help, copyToDialog1, chooseInSticks, usbThread, preferences
-import os.path, operator, subprocess, dbus, re, time
+import ownedUsbDisk, help, copyToDialog1, chooseInSticks, usbThread
+import diskFull, preferences
+import os.path, operator, subprocess, dbus, re, time, copy
 from notification import Notification
 import db
 from globaldef import logFileName
 
 # cette donnée est globale, pour être utilisé depuis n'importe quel objet
-globalDiskData=ownedUsbDisk.Available(True,access="firstFat")
+qApp.diskData=ownedUsbDisk.Available(True,access="firstFat")
 
 def firstdir(l):
     """
@@ -76,9 +77,12 @@ class mainWindow(QMainWindow):
         self.applyPreferences()
         self.timer=QTimer()
         self.updateButtons()
-        self.timer.start(2000)
-        self.threads=[]
+        self.oldThreads=set()
+        self.flashTimer=QTimer()
+        self.flashTimer.setSingleShot(True)
+        QObject.connect(self.ui.forceCheckButton, SIGNAL("clicked()"), self.checkDisks)
         QObject.connect(self.timer, SIGNAL("timeout()"), self.checkDisks)
+        QObject.connect(self.flashTimer, SIGNAL("timeout()"), self.normalLCD);
         QObject.connect(self.ui.helpButton, SIGNAL("clicked()"), self.help)
         QObject.connect(self.ui.umountButton, SIGNAL("clicked()"), self.umount)
         QObject.connect(self.ui.toButton, SIGNAL("clicked()"), self.copyTo)
@@ -87,20 +91,31 @@ class mainWindow(QMainWindow):
         QObject.connect(self.ui.preferenceButton, SIGNAL("clicked()"), self.preference)
         QObject.connect(self.ui.tableView, SIGNAL("doubleClicked(const QModelIndex&)"), self.tableClicked)
 
+    def showEvent (self, ev):
+        """
+        modification du comportement du widget original, pour
+        démarrer le timer et les vérifications de baladeurs
+        après construction de la fenêtre seulement
+        """
+        result=QMainWindow.showEvent(self, ev)
+        self.timer.start(20000)
+        self.checkDisks(force=True) # met à jour le compte de disques affiché
+        return result
+        
     def applyPreferences(self):
         """
         Applique les préférences et les options de ligne de commande
         """
-        global globalDiskData
         prefs=db.readPrefs()
         self.workdir=prefs["workdir"]
         # on active les cases à cocher si ça a été réclamé par les options
         # ou par les préférences
         self.checkable=("--check","") in self.opts or ("-c","") in self.opts or prefs["checkable"]
         other=ownedUsbDisk.Available(self.checkable,access="firstFat")
-        globalDiskData=other
+        qApp.diskData=other
         self.header=ownedUsbDisk.uDisk.headers(self.checkable)
         self.connectTableModel(other)
+        # met en ordre par la colonne des propriétaires
         self.t.setSortingEnabled(True)
         self.t.resizeColumnsToContents()
 
@@ -117,7 +132,6 @@ class mainWindow(QMainWindow):
         fonction de rappel pour un double clic sur un élément de la table
         @param idx un QModelIndex
         """
-        global globalDiskData
         c=idx.column()
         r=idx.row()
         h=self.header[c]
@@ -131,31 +145,42 @@ class mainWindow(QMainWindow):
             cmd=u"nautilus '%s'" %idx.data().toString ()
             subprocess.call(cmd, shell=True)
         elif "device-size" in h:
-            path=globalDiskData[r][self.header.index("1device-mount-paths")]
-            cmd =u"df '%s'" %path
-            dfOutput=subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE).communicate()[0].split("\n")[-2]
-            m = re.match("(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+).*", dfOutput).groups()
-            print m
-            dev,total,used,remain,pcent,path=m
+            mount=idx.model().partition(idx).mountPoint()
+            dev,total,used,remain,pcent,path = self.diskSizeData(mount)
             pcent=int(pcent[:-1])
-            from diskFull import mainWindow
-            w=mainWindow(self,pcent,title=path, total=total, used=used)
+            w=diskFull.mainWindow(self,pcent,title=path, total=total, used=used)
             w.show()
         else:
             QMessageBox.warning(None,
                                 QApplication.translate("Dialog","Double-clic non pris en compte",None, QApplication.UnicodeUTF8),
                                 QApplication.translate("Dialog","pas d'action pour l'attribut %1",None, QApplication.UnicodeUTF8).arg(h))
 
+    def diskSizeData(self, rowOrDev):
+        """
+        @param rowOrDev a row number in the tableView, or a device string
+        @return a tuple dev,total,used,remain,pcent,path for the
+        disk in the given row of the tableView
+        (the tuple comes from the command df)
+        """
+        if type(rowOrDev)==type(0):
+            path=qApp.diskData[rowOrDev][self.header.index("1device-mount-paths")]
+        else:
+            path=rowOrDev
+        cmd =u"df '%s'" %path
+        dfOutput=subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE).communicate()[0].split("\n")[-2]
+        m = re.match("(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+).*", dfOutput).groups()
+        return m
+
+
     def diskFromTableRow(self,ligne):
         """
         trouve le disque qui correspond à une ligne du tableau
         @param ligne la ligne du tableau qui concerne une clé
         @return le disque correspondant à la ligne de tableau (type uDisk)
         """
-        global globalDiskData
-        stickid=globalDiskData[ligne][self.header.index("5drive-serial")]
+        stickid=qApp.diskData[ligne][self.header.index("5drive-serial")]
         found=False
-        for d in globalDiskData.disks.keys():
+        for d in qApp.diskData.disks.keys():
             if d.showableProp("drive-serial")==stickid:
                 found=True
                 break
@@ -169,11 +194,10 @@ class mainWindow(QMainWindow):
         Édition du propriétaire d'une clé.
         @param ligne la ligne du tableau qui concerne une clé
         """
-        global globalDiskData
-        student=globalDiskData[ligne][1]
+        student=qApp.diskData[ligne][1]
         ownedUsbDisk.editRecord(self.diskFromTableRow(ligne), student)
         other=ownedUsbDisk.Available(self.checkable,access="firstFat")
-        globalDiskData=other
+        qApp.diskData=other
         self.connectTableModel(other)
         
     def updateButtons(self):
@@ -184,8 +208,7 @@ class mainWindow(QMainWindow):
         active. Par contre démonter les clés quand elles sont absentes ça
         n'a pas d'utilité.
         """
-        global globalDiskData
-        if len(globalDiskData)>0:
+        if len(qApp.diskData)>0:
             self.ui.toButton.setEnabled(True)
             self.ui.fromButton.setEnabled(True)
             self.ui.umountButton.setEnabled(True)
@@ -211,7 +234,6 @@ class mainWindow(QMainWindow):
         """
         Lance l'action de supprimer des fichiers ou des répertoires dans les clés USB
         """
-        global globalDiskData
         titre1=QApplication.translate("Dialog","Choix de fichiers à supprimer",None, QApplication.UnicodeUTF8)
         titre2=QApplication.translate("Dialog","Choix de fichiers à supprimer (jokers autorisés)",None, QApplication.UnicodeUTF8)
         d=chooseInSticks.chooseDialog(self, titre1, titre2)
@@ -222,11 +244,11 @@ class mainWindow(QMainWindow):
                                        QApplication.translate("Dialog","Vous allez effacer plusieurs baladeurs",None, QApplication.UnicodeUTF8),
                                        QApplication.translate("Dialog","Etes-vous certain de vouloir effacer : "+",".join(pathList),None, QApplication.UnicodeUTF8))
             if reply == QMessageBox.Ok:
-                for p in globalDiskData:
+                for p in qApp.diskData:
                     t=usbThread.threadDeleteInUSB(p,pathList,subdir="Travail", logfile=logFileName)
                     t.setDaemon(True)
-                    self.threads.append(t)
                     t.start()
+                self.checkDisks() # met à jour les symboles d'activité
         else:
             msgBox=QMessageBox.warning(None,
                                        QApplication.translate("Dialog","Aucun fichier sélectionné",None, QApplication.UnicodeUTF8),
@@ -236,16 +258,15 @@ class mainWindow(QMainWindow):
         """
         Lance l'action de copier vers les clés USB
         """
-        global globalDiskData
         d=copyToDialog1.copyToDialog1(parent=self, workdir=self.workdir)
         d.exec_()
         if d.ok==True:
-            for p in globalDiskData:
+            for p in qApp.diskData:
                 subdir=self.workdir
                 t=usbThread.threadCopyToUSB(p,d.selectedList(),subdir=subdir, logfile=logFileName)
                 t.setDaemon(True)
-                self.threads.append(t)
                 t.start()
+            self.checkDisks() # met à jour les symboles d'activité
         else:
             msgBox=QMessageBox.warning(None,
                                        QApplication.translate("Dialog","Aucun fichier sélectionné",None, QApplication.UnicodeUTF8),
@@ -255,7 +276,6 @@ class mainWindow(QMainWindow):
         """
         Lance l'action de copier depuis les clés USB
         """
-        global globalDiskData
         titre1=QApplication.translate("Dialog","Choix de fichiers à copier",None, QApplication.UnicodeUTF8)
         titre2=QApplication.translate("Dialog", "Choix de fichiers à copier depuis les baladeurs", None, QApplication.UnicodeUTF8)
         ok=QApplication.translate("Dialog", "Choix de la destination ...", None, QApplication.UnicodeUTF8)
@@ -275,7 +295,7 @@ class mainWindow(QMainWindow):
                                                    initialPath)
         if destDir and len(destDir)>0 :
             dest=u"%s" %destDir
-            for p in globalDiskData:
+            for p in qApp.diskData:
                 # on devrait vérifier s'il y a des données à copier
                 # et s'il n'y en a pas, ajouter des lignes au journal
                 # mais on va laisser faire ça dans le thread
@@ -286,8 +306,8 @@ class mainWindow(QMainWindow):
                                               dest=dest,
                                               logfile=logFileName)
                 t.setDaemon(True)
-                self.threads.append(t)
                 t.start()
+            self.checkDisks() # met à jour les symboles d'activité
             # on ouvre nautilus pour voir le résultat des copies
             if QMessageBox.question(None,
                                     QApplication.translate("Dialog","Voir les copies",None, QApplication.UnicodeUTF8),
@@ -313,7 +333,6 @@ class mainWindow(QMainWindow):
         """
         Démonte et détache les clés USB affichées
         """
-        global globalDiskData
         buttons=QMessageBox.StandardButtons(QMessageBox.Ok+QMessageBox.Cancel)
         button=QMessageBox.critical ( self,
                                       QApplication.translate("Main","Démontage des baladeurs",None, QApplication.UnicodeUTF8),
@@ -322,12 +341,12 @@ class mainWindow(QMainWindow):
         if button!=QMessageBox.Ok:
             return
         # on parcourt les premières partition FAT
-        for p in globalDiskData:
+        for p in qApp.diskData:
             # on trouve leurs disques parents
-            for d in globalDiskData.disks.keys():
-                if p in globalDiskData.disks[d] and p.selected:
+            for d in qApp.diskData.disks.keys():
+                if p in qApp.diskData.disks[d] and p.selected:
                     # démontage de toutes les partitions du même disque parent
-                    for partition in globalDiskData.disks[d]:
+                    for partition in qApp.diskData.disks[d]:
                         devfile=partition.getProp("device-file-by-id")
                         if isinstance(devfile, dbus.Array):
                             devfile=devfile[0]
@@ -338,6 +357,7 @@ class mainWindow(QMainWindow):
                         devfile_disk=devfile_disk[0]
                     subprocess.call("udisks --detach %s" %devfile_disk, shell=True)
                     break
+        self.checkDisks() # remet à jour le compte de disques
                 
 
     def connectTableModel(self, data):
@@ -356,24 +376,52 @@ class mainWindow(QMainWindow):
         if self.checkable:
             self.t.setItemDelegateForColumn(0, CheckBoxDelegate(self))
             self.t.setItemDelegateForColumn(1, UsbDiskDelegate(self))
+            self.t.setItemDelegateForColumn(3, DiskSizeDelegate(self))
         else:
             self.t.setItemDelegateForColumn(0, UsbDiskDelegate(self))
+            self.t.setItemDelegateForColumn(2, DiskSizeDelegate(self))
         
-    def checkDisks(self):
+    def checkDisks(self, force=False):
         """
         fonction relancée périodiquement pour vérifier s'il y a un changement
         dans le baladeurs, et signaler dans le tableau les threads en cours.
         Le tableau est complètement régénéré à chaque fois, ce qui n'est pas
         toujours souhaitable.
+        À la fin de chaque vérification, un court flash est déclenché sur
+        l'afficheur de nombre de baladeurs connectés et sa valeur est mise à
+        jour.
+        @param force pour forcer une mise à jour du tableau
         """
-        global globalDiskData
         other=ownedUsbDisk.Available(self.checkable,access="firstFat")
-        globalDiskData=other
-        self.connectTableModel(other)
-        self.updateButtons()
-        self.t.resizeColumnsToContents()
+        if force or not self.sameDiskData(qApp.diskData, other):
+            qApp.diskData=other
+            self.oldThreads=copy.copy(usbThread.globalThreads.threadSet())
+            connectedCount=int(other)
+            self.connectTableModel(other)
+            self.updateButtons()
+            self.t.resizeColumnsToContents()
+            self.ui.lcdNumber.display(connectedCount)
+        self.flashLCD()
+        self.t.sortByColumn(2)
 
+    def sameDiskData(self, one, two):
+        """
+        @return True si les ensembles de uniqueId de one et two sont identiques, et si les informations sur les threads n'ont pas varié
+        """
+        return set([p.uniqueId() for p in one]) == set([p.uniqueId() for p in two]) and self.oldThreads == usbThread.globalThreads.threadSet()
 
+    def flashLCD(self):
+        """
+        change le style de l'afficheur LCD pendant une fraction de seconde
+        """
+        self.ui.lcdNumber.setBackgroundRole(QPalette.Highlight)
+        self.flashTimer.start(250) ## un quart de seconde
+
+    def normalLCD(self):
+        """
+        remet le style par défaut pour l'afficheur LCD
+        """
+        self.ui.lcdNumber.setBackgroundRole(QPalette.Window)
 
 class usbTableModel(QAbstractTableModel):
     """
@@ -411,6 +459,13 @@ class usbTableModel(QAbstractTableModel):
             return True
         else:
             return QAbstractTableModel.setData(self, index, role)
+
+    def partition(self, index):
+        """
+        @param index in QModelIndex
+        @return la partition pointée par index
+        """
+        return self.donnees[index.row()][-1]
         
     def data(self, index, role): 
         if not index.isValid(): 
@@ -503,7 +558,6 @@ class UsbDiskDelegate(QStyledItemDelegate):
         self.busyPixmap=QPixmap("/usr/share/icons/Tango/16x16/actions/view-refresh.png")
 
     def paint(self, painter, option, index):
-        global globalDiskData
         text = index.model().data(index, Qt.DisplayRole).toString()
         rect0=QRect(option.rect)
         rect1=QRect(option.rect)
@@ -519,3 +573,37 @@ class UsbDiskDelegate(QStyledItemDelegate):
         else:
             QApplication.style().drawItemPixmap (painter, rect0, Qt.AlignCenter, self.okPixmap)
         
+class DiskSizeDelegate(QStyledItemDelegate):
+    def __init__(self, parent):
+        QStyledItemDelegate.__init__(self,parent)
+        
+
+    def paint(self, painter, option, index):
+        value = int(index.model().data(index, Qt.DisplayRole).toString())
+        text = self.val2txt(value)
+        rect0=QRect(option.rect)
+        rect1=QRect(option.rect)
+        rect0.translate(2,(rect0.height()-16)/2)
+        rect0.setSize(QSize(16,16))
+        rect1.translate(20,0)
+        rect1.setWidth(rect1.width()-20)
+        QApplication.style().drawItemText (painter, rect1, Qt.AlignLeft+Qt.AlignVCenter, option.palette, True, text)
+        # dessin d'un petit cercle pour l'occupation
+        mount=index.model().partition(index).mountPoint()
+        dev,total,used,remain,pcent,path = self.parent().diskSizeData(mount)
+        pcent=int(pcent[:-1])
+        painter.setBrush(QBrush(QColor("slateblue")))
+        painter.drawPie(rect0,0,16*360*pcent/100)
+
+    def val2txt(self, val):
+        """
+        @return a string with a value with unit K, M, or G
+        """
+        suffixes=["B", "KB", "MB", "GB", "TB"]
+        val*=1.0 # calcul flottant
+        i=0
+        while val > 1024 and i < len(suffixes):
+            i+=1
+            val/=1024
+        return "%4.1f %s" %(val, suffixes[i])
+    
