@@ -70,37 +70,38 @@ class uDisk(usbDisk.uDisk,QObject):
 
     def uniqueId(self):
         """
-        renvoie un identifiant unique.
-        reprend l'Uuid hérité de la classe parente, mais y ajoute
-        un nombre supplémentaire, éventuellement placé par "tatouage"
-        sur la clé.
-        @return un identifiant supposément unique
+        @return un identifiant unique, composé du nom du propriétaire
+        suivi du tatouage
         """
-        return "%s~%s" %(self.getFatUuid(), self.tattoo())
+        return "%s~%s" %(self.owner, self.tattoo())
 
     def tattoo(self):
         """
         Renvoie un tatouage présent sur la clé, quitte à le créer.
         @result un tatouage, supposément unique.
         """
-        fatPath=self.getFirstFat().ensureMounted()
-        tattooFileName=os.path.join(fatPath,".scolasync-tattoo")
-        if os.path.exists(tattooFileName):
-            tattoo_=open(tattooFileName,"r").read()
-            # on vérifie par acquis de conscience, qu'il n'existe pas
-            # un tatouage identique dans la base de données
-            # s'il est déjà présent : on le change. Il faudrait
-            # probablement aussi prévenir le prof !!!
-            if tattoo_ in db.tattooList():
+        ff=self.getFirstFat()
+        if ff:
+            fatPath=ff.ensureMounted()
+            tattooFileName=os.path.join(fatPath,".scolasync-tattoo")
+            if os.path.exists(tattooFileName):
+                tattoo_=open(tattooFileName,"r").read()
+                # on vérifie par acquis de conscience, qu'il n'existe pas
+                # un tatouage identique dans la base de données
+                # s'il est déjà présent : on le change. Il faudrait
+                # probablement aussi prévenir le prof !!!
+                if tattoo_ in db.tattooList():
+                    tattoo_="%12.2f" %time.time()
+                    time.sleep(0.05)
+            else:
                 tattoo_="%12.2f" %time.time()
                 time.sleep(0.05)
+                outfile=open(tattooFileName,"w")
+                outfile.write(tattoo_)
+                outfile.close()
+            return tattoo_
         else:
-            tattoo_="%12.2f" %time.time()
-            time.sleep(0.05)
-            outfile=open(tattooFileName,"w")
-            outfile.write(tattoo_)
-            outfile.close()
-        return tattoo_
+            return ""
     
     def readQuirks (self):
         """
@@ -165,9 +166,11 @@ class uDisk(usbDisk.uDisk,QObject):
         Fait en sorte que la deuxième colonne soit toujours le propriétaire
         @param n un nombre
         @param checkable vrai si on doit renvoyer une propriété supplémentaire pour n==0
-        @return si checkable est vrai, un élément si n>0, et le drapeau self.selected si n==0 ; sinon un élément de façon ordinaire. Les noms des éléments sont dans la liste self.itemNames
+        @return si n==-1, renvoie self ; si checkable est vrai, renvoie un élément si n>0, et le drapeau self.selected si n==0 ; sinon un élément de façon ordinaire. Les noms des éléments sont dans la liste self.itemNames
         """
         propListe=usbDisk.uDisk.headers()
+        if n == -1:
+            return self # pour accéder à toutes les données d'une partition
         if self.checkable:
             if n==0:
                 return self.selected
@@ -244,14 +247,15 @@ class Available(usbDisk.Available):
             for d in self.disks.keys():
                 if ud.master() == d.path:
                     self.disks[d].append(ud)
-        ### on fabrique la liste des premières partitions FAT
-        self.firstFats = self.getFirstFats()
+        ### on s'assure que chaque disque a bien un propriétaire
+        ### sinon on le demande
+        self.getFirstFats() # premier passage, pour repérer chaque partition FAT
+        for d in self.disks.keys():
+            d.owner=d.ensureOwner()
+        ### on fabrique la liste des premières partitions FAT,
+        ### en positionnant les attributs de propriétaire
+        self.firstFats = self.getFirstFats(setOwners=True)
         ### on monte les partitions si nécessaire
         if self.access=="firstFat":
             for p in self.firstFats:
                 p.ensureMounted()
-        ### on s'assure que chaque disque a bien un propriétaire
-        ### sinon on le demande
-        for d in self.disks.keys():
-            d.owner=d.ensureOwner()
-    
