@@ -62,7 +62,7 @@ class uDisk:
     _itemNames={
         "1device-mount-paths":QApplication.translate("uDisk","point de montage",None, QApplication.UnicodeUTF8),
         "2device-size":QApplication.translate("uDisk","taille",None, QApplication.UnicodeUTF8),
-        "3drive-vendor":QApplication.translate("uDisk","vendeur",None, QApplication.UnicodeUTF8),
+        "3drive-vendor":QApplication.translate("uDisk","marque",None, QApplication.UnicodeUTF8),
         "4drive-model":QApplication.translate("uDisk","modèle de disque",None, QApplication.UnicodeUTF8),
         "5drive-serial":QApplication.translate("uDisk","numéro de série",None, QApplication.UnicodeUTF8),
         }
@@ -299,10 +299,6 @@ class uDisk:
         @result la première partition VFAT ou None s'il n'y en a pas
         """
         if self.isDosFat(): return self
-        ## if self.firstFat==None:
-        ##     # alors le parcours des clés USB n'a pas encore été fait.
-        ##     # on fait le parcours.
-        ##     fake=Available(access="firstFat")
         return self.firstFat
     
     def ensureMounted(self):
@@ -377,6 +373,12 @@ class Available:
             for p in self.firstFats:
                 p.ensureMounted()
 
+    def __trunc__(self):
+        """
+        @return le nombre de medias connectés
+        """
+        return len(self.firstFats)
+
     def compare(self, other):
         """
         Sert à comparer deux collections de disques, par exemple
@@ -451,12 +453,15 @@ class Available:
         elif self.access=="firstFat":
             return len(self.firstFats)
 
-    def getFirstFats(self):
+    def getFirstFats(self, setOwners=False):
         """
         Facilite l'accès aux partitions de type DOS-FAT, et a un effet de bord :
         marque le disque avec l'uuid de la première partition FAT.
+        @param setOwners si égale à True,
+          signale que la liste devra comporter des attributs de propriétaire
+          de medias.
         @return une liste de partitions, constituée de la première
-        partition de type FAT de chaque disque USB connecté
+          partition de type FAT de chaque disque USB connecté
         """
         result=[]
         for d in self.disks.keys():
@@ -470,6 +475,8 @@ class Available:
                     d.fatuuid=p.uuid
                     d.firstFat=p
                     p.fatuuid=p.uuid
+                    if setOwners:
+                        p.owner=d.owner
                     break
         return result
 
