@@ -68,6 +68,16 @@ class ThreadRegister:
             return self.dico[owner]
         return []
 
+    def threadSet(self):
+        """
+        renvoie l'ensemble des threads actifs
+        """
+        result=set()
+        for o in self.dico.keys():
+            for t in self.dico[o]:
+                result.add(t)
+        return result
+            
 globalThreads=ThreadRegister()
 
 def _sanitizePath(path):
